@@ -25,6 +25,7 @@ from sphinx.application import Sphinx
 from sphinx.util import logging
 
 from . import __version__
+from .icons import ICONS
 
 logger = logging.getLogger(__name__)
 
@@ -49,37 +50,35 @@ def _collapsible_nav(tree: BeautifulSoup) -> None:
     Second, an icon is inserted right before the link.
     Adding the icon as separate DOM element allows click events to be
     captured separately between the icon and the link.
-
-    The icon is from the Materials icons set:
-    https://material.io/resources/icons/?icon=chevron_right
     """
     for link in tree.select(".nav-toc a"):
-        # First, all links should be wrapped in a div.nav-link
-        link.wrap(tree.new_tag("div", attrs={"class": "nav-link"}))
-        # Next, insert a span.expand before the link, if the #nav-link
-        # has any sibling elements (a ``ul`` in the navigation menu)
-        if link.parent.next_sibling:
-            # create the icon
-            svg = tree.new_tag(
-                "svg",
-                attrs={
-                    "xmlns": "http://www.w3.org/2000/xvg",
-                    "viewBox": "0 0 24 24",
-                    "class": "expand",
-                    "fill": "currentColor",
-                },
-            )
-            path = tree.new_tag(
-                "path", d="M10 6L8.59 7.41 13.17 12l-4.58 4.59L10 18l6-6z"
-            )
-            svg.append(path)
-            link.insert_before(svg)
+        # Don't add the nav-link class twice (#166)
+        if "nav-link" not in link.parent.get("class", []):
+            # First, all links should be wrapped in a div.nav-link
+            link.wrap(tree.new_tag("div", attrs={"class": "nav-link"}))
+            # Next, insert a span.expand before the link, if the #nav-link
+            # has any sibling elements (a ``ul`` in the navigation menu)
+            if link.parent.next_sibling:
+                # create the icon
+                svg = BeautifulSoup(ICONS["chevron_right"], "html.parser")
+                link.insert_before(svg)
 
 
 def _expand_current(tree: BeautifulSoup) -> None:
     """Add the ``.expanded`` class to li.current elements."""
     for li in tree("li", class_="current"):
-        li["class"] += ["expanded"]
+        if "expanded" not in li.get("class", []):
+            li["class"] += ["expanded"]
+
+
+def _remove_span_pre(tree: BeautifulSoup) -> None:
+    """Unwrap unnecessary spans.
+
+    This gets added by visit_Text(). If I overwrite it there,
+    it's 20 lines of code for only 1 line of change.
+    """
+    for span in tree("span", class_="pre"):
+        span.unwrap()
 
 
 def _modify_html(html_filename: str) -> None:
@@ -92,11 +91,12 @@ def _modify_html(html_filename: str) -> None:
     After these modifications, the HTML is written into a file,
     overwriting the original file.
     """
-    with open(html_filename) as html:
+    with open(html_filename, encoding="utf-8") as html:
         tree = BeautifulSoup(html, "html.parser")
 
     _expand_current(tree)
     _collapsible_nav(tree)
+    _remove_span_pre(tree)
 
     with open(html_filename, "w") as out_file:
         out_file.write(str(tree))
@@ -121,7 +121,6 @@ def post_process_html(app: Sphinx, exc: Optional[Exception]) -> None:
 
 def setup(app: "Sphinx") -> Dict[str, Any]:
     """Set this up as internal extension."""
-    app.add_config_value("mark_external_links", True, "env")
     app.connect("build-finished", post_process_html)
 
     return {
